//+------------------------------------------------------------------+
//|                                                    DIGISTOCH.mq4 |
//|                      Copyright  2006, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright  2006, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"

/*********************************************************************
* Author: Muhammad Hamizi Jaminan (hymns@forex-tsd hymns@forexfactory)
*
* Date: January 3, 2007
* Custom Indicator: DigiStoch.mq4
* Version: 1.0.2
* Description: Multi TimeFrame Digital Stochastic Indicator
*
* Change Logs
* Version 1.0.2
* - Reused function to reduce memory when create new object  
*
* Version 1.0.1
* - Fix little bugs for color and arrow. When price overbought or  
*   oversold color change to bearish or bullish begin color. Should be 
*   overbought or oversold color and arrow.
*
* Version 1.0
* - Release DigiStoch ;)
**********************************************************************/

#property indicator_separate_window

extern int K_period = 8;
extern int D_period = 3;
extern int S_period = 3;
extern bool Show_Stoch_Value = true;
extern bool Show_Legend = true;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   IndicatorShortName("DIGISTOCH");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   ObjectDelete("Label_1"); ObjectDelete("Label_2"); ObjectDelete("Label_3");
   ObjectDelete("Signal1"); ObjectDelete("Signal2"); ObjectDelete("Signal3"); ObjectDelete("Signal4"); ObjectDelete("Signal5"); ObjectDelete("Signal6");
   ObjectDelete("DataValue1"); ObjectDelete("DataValue2"); ObjectDelete("DataValue3"); ObjectDelete("DataValue4"); ObjectDelete("DataValue5"); ObjectDelete("DataValue6");
   ObjectDelete("DataArrow1"); ObjectDelete("DataArrow2"); ObjectDelete("DataArrow3"); ObjectDelete("DataArrow4"); ObjectDelete("DataArrow5"); ObjectDelete("DataArrow6");
   ObjectDelete("Legend1"); ObjectDelete("Legend2"); ObjectDelete("Legend3"); ObjectDelete("Legend4"); ObjectDelete("Legend5"); ObjectDelete("Legend6");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {    
    //m1 data
    double stoch_main_m1 = iStochastic(NULL,PERIOD_M1,K_period,D_period,S_period,MODE_SMA,1,MODE_MAIN,0);
    double stoch_sig_m1 = iStochastic(NULL,PERIOD_M1,K_period,D_period,S_period,MODE_SMA,1,MODE_SIGNAL,0);

    //m5 data
    double stoch_main_m5 = iStochastic(NULL,PERIOD_M5,K_period,D_period,S_period,MODE_SMA,1,MODE_MAIN,0);
    double stoch_sig_m5 = iStochastic(NULL,PERIOD_M5,K_period,D_period,S_period,MODE_SMA,1,MODE_SIGNAL,0);

    //m15 data
    double stoch_main_m15 = iStochastic(NULL,PERIOD_M15,K_period,D_period,S_period,MODE_SMA,1,MODE_MAIN,0);
    double stoch_sig_m15 = iStochastic(NULL,PERIOD_M15,K_period,D_period,S_period,MODE_SMA,1,MODE_SIGNAL,0);
    
    //m30 data
    double stoch_main_m30 = iStochastic(NULL,PERIOD_M30,K_period,D_period,S_period,MODE_SMA,1,MODE_MAIN,0);
    double stoch_sig_m30 = iStochastic(NULL,PERIOD_M30,K_period,D_period,S_period,MODE_SMA,1,MODE_SIGNAL,0);

    //h1 data
    double stoch_main_h1 = iStochastic(NULL,PERIOD_H1,K_period,D_period,S_period,MODE_SMA,1,MODE_MAIN,0);
    double stoch_sig_h1 = iStochastic(NULL,PERIOD_H1,K_period,D_period,S_period,MODE_SMA,1,MODE_SIGNAL,0);

    //h4 data
    double stoch_main_h4 = iStochastic(NULL,PERIOD_H4,K_period,D_period,S_period,MODE_SMA,1,MODE_MAIN,0);
    double stoch_sig_h4 = iStochastic(NULL,PERIOD_H4,K_period,D_period,S_period,MODE_SMA,1,MODE_SIGNAL,0);
    
    //define color
    color stoch_color_m1, stoch_color_m5, stoch_color_m15, stoch_color_m30, stoch_color_h1, stoch_color_h4;

    //define string    
    string stoch_level_m1, stoch_level_m5, stoch_level_m15, stoch_level_m30, stoch_level_h1, stoch_level_h4,
           stoch_arrow_m1, stoch_arrow_m5, stoch_arrow_m15, stoch_arrow_m30, stoch_arrow_h1, stoch_arrow_h4;
    
    //m1 up trend
    if ((stoch_main_m1 >= stoch_sig_m1) && (stoch_sig_m1 < 20) && (stoch_sig_m1 != 0)) { stoch_color_m1 = YellowGreen; }
    if ((stoch_main_m1 >= stoch_sig_m1) && (stoch_sig_m1 >= 20) && (stoch_sig_m1 <= 80)) { stoch_color_m1 = Lime; }
    if ((stoch_main_m1 >= stoch_sig_m1) && (stoch_sig_m1 > 80)) { stoch_color_m1 = Green; }

    //m1 down trend
    if ((stoch_main_m1 <= stoch_sig_m1) && (stoch_sig_m1 > 80) && (stoch_sig_m1 != 100)) { stoch_color_m1 = Tomato; }
    if ((stoch_main_m1 <= stoch_sig_m1) && (stoch_sig_m1 >= 20) && (stoch_sig_m1 <= 80)) { stoch_color_m1 = Red; }
    if ((stoch_main_m1 <= stoch_sig_m1) && (stoch_sig_m1 < 20)) { stoch_color_m1 = FireBrick; }

    //m5 up trend
    if ((stoch_main_m5 >= stoch_sig_m5) && (stoch_sig_m5 < 20) && (stoch_sig_m5 != 0)) { stoch_color_m5 = YellowGreen; }
    if ((stoch_main_m5 >= stoch_sig_m5) && (stoch_sig_m5 >= 20) && (stoch_sig_m5 <= 80)) { stoch_color_m5 = Lime; }
    if ((stoch_main_m5 >= stoch_sig_m5) && (stoch_sig_m5 > 80)) { stoch_color_m5 = Green; }

    //m5 down trend
    if ((stoch_main_m5 <= stoch_sig_m5) && (stoch_sig_m5 > 80) && (stoch_sig_m5 != 100)) { stoch_color_m5 = Tomato; }    
    if ((stoch_main_m5 <= stoch_sig_m5) && (stoch_sig_m5 >= 20) && (stoch_sig_m5 <= 80)) { stoch_color_m5 = Red; }
    if ((stoch_main_m5 <= stoch_sig_m5) && (stoch_sig_m5 < 20)) { stoch_color_m5 = FireBrick; }

    //m15 up trend
    if ((stoch_main_m15 >= stoch_sig_m15) && (stoch_sig_m15 < 20) && (stoch_sig_m15 != 0)) { stoch_color_m15 = YellowGreen; }
    if ((stoch_main_m15 >= stoch_sig_m15) && (stoch_sig_m15 >= 20) && (stoch_sig_m15 <= 80)) { stoch_color_m15 = Lime; }
    if ((stoch_main_m15 >= stoch_sig_m15) && (stoch_sig_m15 > 80)) { stoch_color_m15 = Green; }

    //m15 down trend
    if ((stoch_main_m15 <= stoch_sig_m15) && (stoch_sig_m15 > 80) && (stoch_sig_m15 != 100)) { stoch_color_m15 = Tomato; }
    if ((stoch_main_m15 <= stoch_sig_m15) && (stoch_sig_m15 >= 20) && (stoch_sig_m15 <= 80)) { stoch_color_m15 = Red; }
    if ((stoch_main_m15 <= stoch_sig_m15) && (stoch_sig_m15 < 20)) { stoch_color_m15 = FireBrick; }
       
    //m30 up trend
    if ((stoch_main_m30 >= stoch_sig_m30) && (stoch_sig_m30 < 20) && (stoch_sig_m30 != 0)) { stoch_color_m30 = YellowGreen; }
    if ((stoch_main_m30 >= stoch_sig_m30) && (stoch_sig_m30 >= 20) && (stoch_sig_m30 <= 80)) { stoch_color_m30 = Lime; }
    if ((stoch_main_m30 >= stoch_sig_m30) && (stoch_sig_m30 > 80)) { stoch_color_m30 = Green; }

    //m30 down trend
    if ((stoch_main_m30 <= stoch_sig_m30) && (stoch_sig_m30 > 80) && (stoch_sig_m30 != 100)) { stoch_color_m30 = Tomato; }
    if ((stoch_main_m30 <= stoch_sig_m30) && (stoch_sig_m30 >= 20) && (stoch_sig_m30 <= 80)) { stoch_color_m30 = Red; }
    if ((stoch_main_m30 <= stoch_sig_m30) && (stoch_sig_m30 < 20)) { stoch_color_m30 = FireBrick; }

    //h1 up trend
    if ((stoch_main_h1 >= stoch_sig_h1) && (stoch_sig_h1 < 20) && (stoch_sig_h1 != 0)) { stoch_color_h1 = YellowGreen; }
    if ((stoch_main_h1 >= stoch_sig_h1) && (stoch_sig_h1 >= 20) && (stoch_sig_h1 <= 80)) { stoch_color_h1 = Lime; }
    if ((stoch_main_h1 >= stoch_sig_h1) && (stoch_sig_h1 > 80)) { stoch_color_h1 = Green; }
    
    //h1 down trend
    if ((stoch_main_h1 <= stoch_sig_h1) && (stoch_sig_h1 > 80) && (stoch_sig_h1 != 100)) { stoch_color_h1 = Tomato; }
    if ((stoch_main_h1 <= stoch_sig_h1) && (stoch_sig_h1 >= 20) && (stoch_sig_h1 <= 80)) { stoch_color_h1 = Red; }
    if ((stoch_main_h1 <= stoch_sig_h1) && (stoch_sig_h1 < 20)) { stoch_color_h1 = FireBrick; }

    //h4 up trend
    if ((stoch_main_h4 >= stoch_sig_h4) && (stoch_sig_h4 < 20) && (stoch_sig_h4 != 0)) { stoch_color_h4 = YellowGreen; }    
    if ((stoch_main_h4 >= stoch_sig_h4) && (stoch_sig_h4 >= 20) && (stoch_sig_h4 <= 80)) { stoch_color_h4 = Lime; }
    if ((stoch_main_h4 >= stoch_sig_h4) && (stoch_sig_h4 > 80)) { stoch_color_h4 = Green; }
    
    //h4 down trend
    if ((stoch_main_h4 <= stoch_sig_h4) && (stoch_sig_h4 > 80) && (stoch_sig_h4 != 100)) { stoch_color_h4 = Tomato; }
    if ((stoch_main_h4 <= stoch_sig_h4) && (stoch_sig_h4 >= 20) && (stoch_sig_h4 <= 80)) { stoch_color_h4 = Red; }
    if ((stoch_main_h4 <= stoch_sig_h4) && (stoch_sig_h4 < 20)) { stoch_color_h4 = FireBrick; }
    
    //Label1
    ObjectDraw("DIGISTOCH", "Label_1", "SIGNAL", "Arial Bold", 8, Silver, 105, 3);                

    //Stoch Signal
    ObjectDraw("DIGISTOCH", "Signal1", "M1", "Arial Bold", 9, stoch_color_m1, 150, 3);                
    ObjectDraw("DIGISTOCH", "Signal2", "M5", "Arial Bold", 9, stoch_color_m5, 175, 3);                
    ObjectDraw("DIGISTOCH", "Signal3", "M15", "Arial Bold", 9, stoch_color_m15, 200, 3);                    
    ObjectDraw("DIGISTOCH", "Signal4", "M30", "Arial Bold", 9, stoch_color_m30, 230, 3);                    
    ObjectDraw("DIGISTOCH", "Signal5", "H1", "Arial Bold", 9, stoch_color_h1, 260, 3);                
    ObjectDraw("DIGISTOCH", "Signal6", "H4", "Arial Bold", 9, stoch_color_h4, 280, 3);                
    

    //Show Digital Stochastic Value
    if (Show_Stoch_Value == true) 
    { 
       //Arrow M1
       if (stoch_main_m1 >= stoch_sig_m1 && stoch_sig_m1 > 0) { stoch_arrow_m1 = ""; }
       if (stoch_main_m1 <= stoch_sig_m1 && stoch_sig_m1 < 100) { stoch_arrow_m1 = ""; }

       //Arrow M5
       if (stoch_main_m5 >= stoch_sig_m5 && stoch_sig_m5 > 0) { stoch_arrow_m5 = ""; }
       if (stoch_main_m5 <= stoch_sig_m5 && stoch_sig_m5 < 100) { stoch_arrow_m5 = ""; }

       //Arrow M15
       if (stoch_main_m15 >= stoch_sig_m15 && stoch_sig_m15 > 0) { stoch_arrow_m15 = ""; }
       if (stoch_main_m15 <= stoch_sig_m15 && stoch_sig_m15 < 100) { stoch_arrow_m15 = ""; }

       //Arrow M30
       if (stoch_main_m30 >= stoch_sig_m30 && stoch_sig_m30 > 0) { stoch_arrow_m30 = ""; }
       if (stoch_main_m30 <= stoch_sig_m30 && stoch_sig_m30 < 100) { stoch_arrow_m30 = ""; }

       //Arrow H1
       if (stoch_main_h1 >= stoch_sig_h1 && stoch_sig_h1 > 0) { stoch_arrow_h1 = ""; }
       if (stoch_main_h1 <= stoch_sig_h1 && stoch_sig_h1 < 100) { stoch_arrow_h1 = ""; }

       //Arrow H4
       if (stoch_main_h4 >= stoch_sig_h4 && stoch_sig_h4 > 0) { stoch_arrow_h4 = ""; }
       if (stoch_main_h4 <= stoch_sig_h4 && stoch_sig_h4 < 100) { stoch_arrow_h4 = ""; }

       //Label2
       ObjectDraw("DIGISTOCH", "Label_2", "STOCHASTIC", "Arial Bold", 8, Silver, 310, 3);                

       //Data M1
       ObjectDraw("DIGISTOCH", "DataValue1", "M1  : "+StringSubstr(DoubleToStr(stoch_sig_m1,4),0,5), "Arial Bold", 8, stoch_color_m1, 380, 2);                            
       ObjectDraw("DIGISTOCH", "DataArrow1", stoch_arrow_m1, "Wingdings", 8, stoch_color_m1, 435, 2);                            

       //Data M30
       ObjectDraw("DIGISTOCH", "DataValue2", "M30: "+StringSubstr(DoubleToStr(stoch_sig_m30,4),0,5), "Arial Bold", 8, stoch_color_m30, 380, 12);                            
       ObjectDraw("DIGISTOCH", "DataArrow2", stoch_arrow_m30, "Wingdings", 8, stoch_color_m30, 435, 13);                            

       //Data M5        
       ObjectDraw("DIGISTOCH", "DataValue3", "M5: "+StringSubstr(DoubleToStr(stoch_sig_m5,4),0,5), "Arial Bold", 8, stoch_color_m5, 460, 2);                            
       ObjectDraw("DIGISTOCH", "DataArrow3", stoch_arrow_m5, "Wingdings", 8, stoch_color_m5, 510, 3);                            

       //Data H1
       ObjectDraw("DIGISTOCH", "DataValue4", "H1 : "+StringSubstr(DoubleToStr(stoch_sig_h1,4),0,5), "Arial Bold", 8, stoch_color_h1, 460, 12);                            
       ObjectDraw("DIGISTOCH", "DataArrow4", stoch_arrow_h1, "Wingdings", 8, stoch_color_h1, 510, 13);                            

       //Data M15
       ObjectDraw("DIGISTOCH", "DataValue5", "M15: "+StringSubstr(DoubleToStr(stoch_sig_m15,4),0,5), "Arial Bold", 8, stoch_color_m15, 535, 2);                            
       ObjectDraw("DIGISTOCH", "DataArrow5", stoch_arrow_m15, "Wingdings", 8, stoch_color_m15, 590, 3);                            

       //Data H4
       ObjectDraw("DIGISTOCH", "DataValue6", "H4   : "+StringSubstr(DoubleToStr(stoch_sig_h4,4),0,5), "Arial Bold", 8, stoch_color_h4, 535, 12);                            
       ObjectDraw("DIGISTOCH", "DataArrow6", stoch_arrow_h4, "Wingdings", 8, stoch_color_h4, 590, 13);                            

    }
            
    //Show Legend
    if (Show_Legend == true) 
    {
       //Label 3
       ObjectDraw("DIGISTOCH", "Label_3", "LEGEND", "Arial Bold", 8, Silver, 615, 3);                
       
       //Legend
       ObjectDraw("DIGISTOCH", "Legend1", "* TREND UP", "Arial Bold", 8, Lime, 665, 2);                
       ObjectDraw("DIGISTOCH", "Legend2", "* TREND DN", "Arial Bold", 8, Red, 665, 12);        
       ObjectDraw("DIGISTOCH", "Legend3", "* OVERBOUGHT", "Arial Bold", 8, Green, 735, 2);
       ObjectDraw("DIGISTOCH", "Legend4", "* OVERSOLD", "Arial Bold", 8, FireBrick, 735, 12);
       ObjectDraw("DIGISTOCH", "Legend5", "* BULLISH START", "Arial Bold", 8, YellowGreen, 825, 2);
       ObjectDraw("DIGISTOCH", "Legend6", "* BEARISH START", "Arial Bold", 8, Tomato, 825, 12);    
    }
//----
    return(0); 
//----
} 

//+------------------------------------------------------------------+
//| Custom indicator drawing function                                |
//+------------------------------------------------------------------+
void ObjectDraw(string WindowsName,string ObjectLabel, string ObjectString, string ObjectFont, int ObjectSize, color ObjectColor, int ObjectDistantX, int ObjectDistantY) {
    ObjectCreate(ObjectLabel, OBJ_LABEL, WindowFind(WindowsName), 0, 0);
    ObjectSetText(ObjectLabel, ObjectString, ObjectSize, ObjectFont, ObjectColor);
    ObjectSet(ObjectLabel, OBJPROP_CORNER, 0);
    ObjectSet(ObjectLabel, OBJPROP_XDISTANCE, ObjectDistantX);
    ObjectSet(ObjectLabel, OBJPROP_YDISTANCE, ObjectDistantY);                      
}
//+------------------------------------------------------------------+